@@ -15,34 +15,33 @@ from dovado_rtl.abstract_classes import AbstractFitnessEvaluator
 class FitnessEvaluator(AbstractFitnessEvaluator):
     def __init__(
         self,
-        approximating: bool,
         nearest_distance: int,
-        estimator: Estimator,
+        estimator: Optional[Estimator],
         evaluator: DesignPointEvaluator,
         config: Configuration,
     ):
         self.__nearest_distance = nearest_distance
-        self.__approximating = approximating
         self.__threshold: int = 0
-        self.__estimator: Estimator = estimator
+        self.__estimator: Optional[Estimator] = estimator
         self.__evaluator: DesignPointEvaluator = evaluator
         self.__config: Configuration = config
-        self.__set_threshold(self.__estimator.get_examples())
+        if self.__estimator:
+            self.__set_threshold(self.__estimator.get_examples())
         self.__last_design_point: Optional[Tuple[int, ...]] = None
 
     @lru_cache()
     def fitness(self, design_point: Tuple[int, ...], metric: Metric):
         # design_point is a Tuple because lists are unhashable
         # and caching is allowed only with hashable parameters
-
-        sample_distance = self.__nth_nearest_distance(
-            list(design_point),
-            self.__estimator.get_examples(),
-            int(self.__nearest_distance),
-        )
-        print("Nth nearest distance: " + str(sample_distance))
+        if self.__estimator:
+            sample_distance = self.__nth_nearest_distance(
+                list(design_point),
+                self.__estimator.get_examples(),
+                int(self.__nearest_distance),
+            )
+            print("Nth nearest distance: " + str(sample_distance))
         if (
-            not self.__approximating
+            not self.__estimator
             or (sample_distance == 0)
             or (sample_distance > self.__threshold)
         ):
@@ -51,7 +50,7 @@ class FitnessEvaluator(AbstractFitnessEvaluator):
             if not full_design_value:
                 raise Exception("Evaluator returned a None design value")
             design_value = full_design_value.value[metric]
-            if design_point != self.__last_design_point:
+            if design_point != self.__last_design_point and self.__estimator:
                 self.__estimator.add_example(
                     Example(list(design_point), full_design_value)
                 )
@@ -114,8 +113,8 @@ class FitnessEvaluator(AbstractFitnessEvaluator):
         largest_list = nlargest(n, distances)
         if len(largest_list) > n - 1:
             return largest_list[n - 1]
-        else:
-            return largest_list[-2]
+
+        return largest_list[-2]
 
     @staticmethod
     def __mean(numbers: List[float]) -> float:
